@@ -24,6 +24,11 @@
 #' The sMC has an attribute "quantile", which is the associated quantile of the
 #' F-distribution, which can be used as a cut-off for significant variables, similar
 #' to the cut-off of 1 associated with the VIP.
+#' 
+#' @details From plsVarSel 0.9.10, the VIP method handles multiple responses
+#' correctly, as does the LW method. All other filter methods implemented in 
+#' this package assume a single response and will give its results based on the
+#' first response in multi-response cases.
 #'
 #' @author Tahir Mehmood, Kristian Hovde Liland, Solve Sæbø.
 #'
@@ -59,11 +64,15 @@
 VIP <- function (pls.object, opt.comp, p = dim(pls.object$coef)[1]) {
   # Variable importance in prediction
   W <- pls.object$loading.weights
+  WW <- W * W/apply(W, 2, function(x) sum(x * x))
   Q <- pls.object$Yloadings
   TT <- pls.object$scores
-  Q2 <- as.numeric(Q) * as.numeric(Q)
+  if(length(dim(Q)) == 0){
+    Q2 <- as.numeric(Q) * as.numeric(Q)
+  } else {
+    Q2 <- rowSums(t(Q * Q))
+  }
   Q2TT <- Q2[1:opt.comp] * diag(crossprod(TT))[1:opt.comp]
-  WW <- W * W/apply(W, 2, function(x) sum(x * x))
   VIP <- sqrt(p * apply(sweep(WW[, 1:opt.comp, drop=FALSE],2,Q2TT,"*"), 1, sum)/sum(Q2TT))
   VIP
 }
